<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>关闭 (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>折叠</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>展开</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>忽略警告</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%1%/%Ln 分钟</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%1% of %Ln word(s)</source>
        <translation>
            <numerusform>%1%/%Ln 字</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln 个字</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln 分钟</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>每日进度</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>终极目标</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>当前目标</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>不可用</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n 天</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;n破折号; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%1% of daily goal</source>
        <translation>每日目标的 %1%</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>设置语言</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(无标题 %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (只读)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>抱歉</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>无法保存 &apos;%1&apos;。</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>保存文件为</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>无法覆盖 &apos;%1&apos;。</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>重命名文件</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>无法重命名 &apos;%1&apos;。</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>重新加载文件？</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>重新从磁盘中加载文件 &apos;%1&apos; ？</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>未保存的更改将丢失。</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>重新加载</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>无标题 %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>问题</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>保存为纯文本将丢弃全部格式。是否要丢弃格式？</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>文件已更改</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>文件  &apos;%1&apos;  已被其他程序更改。</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>您要重新加载文件吗？</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>重新加载</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>忽略</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>文件已删除</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>文件 %1 已被其他程序删除。</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>您是否要保存或关闭该文件？</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>无法打开存档。</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>搜索：</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>替换为：</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>忽略大小写</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>全字匹配</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>正则表达式</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>向上搜索</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>向下搜索</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>查找(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>替换(&amp;R)</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>替换全部(&amp;A)</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>查找</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>替换</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>替换 %n 个实例？</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>询问</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>抱歉</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>没找到词组。</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>odf文本</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>OpenDocument 普通 XML</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>RTF 文本格式</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>纯文本</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>所有文件</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>所有支持的文件</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>检查拼写...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>（找不到建议）</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>打开图像</translation>
    </message>
    <message>
        <source>Images(%1)</source>
        <translation>图像(%1)</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>选择程序语言：</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;系统语言&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>注意</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>要使语言的变化生效，请重新启动本程序。</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>无法打开存档</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>首选项</translation>
    </message>
    <message>
        <source>General</source>
        <translation>常规</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>统计</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>工具栏</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>拼写检查</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>选择词典</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>抱歉</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>无法打开存档。</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>存档不包含可用的词典。</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>询问</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>快捷键</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>一个或多个快捷键冲突。您要继续吗？</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>词典 &quot;%1&quot; 已经存在。您要替换它吗？</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>每日目标</translation>
    </message>
    <message>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>分钟：</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>字数：</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>始终垂直居中</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>块状光标</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>平滑字体</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>打字机声音</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>智能引号：</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>双倍行距</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>单线</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>场景</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>分隔符:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Automatically save changes</source>
        <translation>自动保存更改</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>记住光标位置</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>字数</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>页数</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>段落数</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>字符数</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>字符：</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>段落：</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>字数统计规则</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>将今天的计划进度清零？</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>移除当前词典？</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>对纯文本文件写入字节顺序标记</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>默认格式：</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>界面</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>总是显示滚动条</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>总是显示置顶栏</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>总是显示底边栏</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>重置今日</translation>
    </message>
    <message>
        <source>History</source>
        <translation>历史</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>记住历史</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>显示目标</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>达到目标的最小进度：</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>探测单词边界</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>字符数除以6</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>将每个字母都计算为一个词</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>页数统计算法</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>样式</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>仅图标</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>仅文本</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>文本在图标旁</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>文本在图标下</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>文本位置：</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>动作</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>上移</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>下移</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>添加分隔符</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>命令</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>快捷键</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>动作</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>输入时检查拼写</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>忽略大写单词</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>忽略带数字的单词</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>语言</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>个人词典</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>不支持的RTF文件。</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>意外地跳到了文件末尾.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>向上移动场景</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>打开/关闭场景列表</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>显示场景列表(%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>隐藏场景列表(%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>过滤器</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>向下移动场景</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>调整场景列表大小</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>默认</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>管理会话</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>会话(&amp;E)</translation>
    </message>
    <message>
        <source>New</source>
        <translation>新建</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>副本</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>切换到</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>新会话</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>复制会话</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>重命名会话</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>询问</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>删除所选会话？</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>会话名称：</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>抱歉</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>请求的会话名称已在使用中。</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>新建(&amp;N)...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>管理(&amp;M)...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>恢复默认</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>快捷键：</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>更换引号...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>请等待</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>检查拼写</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>添加(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>忽略(&amp;I)</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>忽略全部(&amp;g)</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>更改(&amp;C)</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>更改全部(&amp;h)</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>不在词典中：</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>更改为：</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>检查拼写...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>请等待</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>从文件开始继续检查？</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>拼写检查完成。</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>符号</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>最近使用过的符号</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>全部符号</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>详情</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>名称：</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>插入</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>块</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>文字</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>无标题 %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>名称：</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>无图像</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>平铺</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>居中</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>拉伸</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>比例</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>缩放</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>不透明度：</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>位置：</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>宽度：</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>圆滑文字背景边角</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>半径：</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>模糊文字背景</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>文字背景阴影</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>垂直偏移量：</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>页边距</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>窗口：</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>页面：</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>首行缩进</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>段前：</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>段后：</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>编辑主题</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>窗口背景</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>类型：</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>颜色：</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>图像：</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation>像素</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>文字背景</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>文本</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>字体：</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>拼写错误：</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>行距</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>单线</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1.5 倍行距</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>双倍行距</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>成比例</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>高度：</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>段间距</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Tab 宽度：</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>新建主题</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>主题</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>默认</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>愤怒的天神</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>魔幻之境</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>柔和蓝</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>保守派</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>太空梦</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>谍战</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>静谧的云端</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>书桌</translation>
    </message>
    <message>
        <source>New</source>
        <translation>新建</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>副本</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>自定义</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>导入</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>导出</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>询问</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>删除主题 &apos;%1&apos;？</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>主题 (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>导入主题</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>导出主题</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>询问</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>删除定时器？</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;单词数：&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;页数：&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;段落数：&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;字符数：&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>设定延迟</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>设定时间</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>延迟：</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>时间：</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>闹铃</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>类型：</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>备忘录：</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>无定时器运行</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>定时器</translation>
    </message>
    <message>
        <source>New</source>
        <translation>新建</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>最近的</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>询问</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>取消编辑定时器吗？</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>载入主题</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>载入声音</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>无标题</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>打开文件</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>关于 FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>一个简洁的全屏文字处理软件</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>版权 &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>以 &lt;a href=%1&gt;GPL 3&lt;/a&gt; 许可协议发布</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>使用 &lt;a href=%1&gt;Oxygen&lt;/a&gt; 图标主题</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>遵照 &lt;a href=%1&gt;LGPL 3&lt;/a&gt; 许可使用</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>字符数：%L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>页数：%L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>段落数：%L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>单词数：%L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>正在打开 %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(无标题 %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>列出所有文档</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>跳转到下一文档</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>跳转到上一文档</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>跳转到第一个文档</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>跳转到最后一个文档</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>跳转到文档 %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>加载设置中</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>紧急缓存是不可写的。</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter 没有完全关闭。</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>从紧急缓存中还原？</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>有些文件无法打开。</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>一些文件以只读方式打开。</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; 比缓存的副本新。</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>覆盖较新的文件？</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>保存更改？</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>在关闭之前保存文件 &apos;%1&apos; ？</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>如果你选择不保存，所有更改都会丢失。</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>无法加载打字机声音。</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>文件(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>新建(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>打开(&amp;O)...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>重新载入(&amp;d)</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>保存(&amp;S)</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>另存为(&amp;A)...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>重命名(&amp;R)...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>全部保存(&amp;L)</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>管理会话</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>新会话</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>打印(&amp;P)...</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>页面设置.(&amp;g)..</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>关闭(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>退出(&amp;Q)</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>编辑(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>撤销(&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>重做(&amp;R)</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>剪切(&amp;T)</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>复制(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>粘贴(&amp;P)</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>无格式粘贴(&amp;U)</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>全选(&amp;A)</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>选择场景(&amp;S)</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>格式(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>标题(&amp;H)</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>标题 &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>标题 &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>标题 &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>标题 &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>标题 &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>标题 &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>普通 (&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>粗体(&amp;B)</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>斜体(&amp;I)</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>下划线(&amp;U)</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>删除线(&amp;K)</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>上标(&amp;E)</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>下标(&amp;S)</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>左对齐(&amp;L)</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>居中(&amp;C)</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>右对齐(&amp;R)</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>两端对齐(&amp;J)</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>减小缩进(&amp;D)</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>增大缩进(&amp;N)</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>从左到右(&amp;F)</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>从右到左 (&amp;G)</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>工具(&amp;T)</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>查找(&amp;F)...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>查找下一个(&amp;N)</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>查找上一个(&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>替换(&amp;R)...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>智能引号(&amp;Q)</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>更新文档(&amp;D)</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>将文档中所有引号更新为智能引号</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>更新所选(&amp;S)</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>将选中的引号更新为智能引号</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>拼写(&amp;S)...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>设置语言(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>定时器(&amp;T)...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>符号...(&amp;y)</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>每日进度(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>设置(&amp;S)</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>显示工具栏(&amp;T)</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>显示菜单图标(&amp;M)</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>聚焦文本(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>全屏(&amp;F)</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>最小化(&amp;I)</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>主题(&amp;T)...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>偏好设置(&amp;P)...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>关闭聚焦</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>聚焦一行</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>聚焦三行</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>段落(&amp;P)</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>聚焦段落</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>帮助(&amp;H)</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>程序语言(&amp;L)...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>某些文件不受支持，无法打开。</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>关闭(&amp;O)</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>单行(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>三行(&amp;T)</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>关于(&amp;A)</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>关于 &amp;Qt</translation>
    </message>
</context>
</TS>
